package RapidApp::Catalyst;

use strict;
use warnings;

die "RapidApp::Catalyst is DEPRECATED - please use Catalyst::Plugin::RapidApp";


1;